@@ -1,7 +1,7 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.3.0Dev
+ *             Automatically Tuned Linear Algebra Software v3.3.3Dev
  **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
- *                    (C) Copyright 1999 R. Clint Whaley                     
+ *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -16,7 +16,7 @@
  *      or promote products derived from this software without specific
  *      written permission.
  *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
  * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
  * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE UNIVERSITY OR CONTRIBUTORS BE
@@ -26,11 +26,11 @@
  * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
  * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE. 
+ * POSSIBILITY OF SUCH DAMAGE.
  *
  */
 
-#define NONE
+#define SREAL
 #include "atlas_misc.h"
 #ifdef ATL_USEPTHREADS
    #include "atlas_ptalias1.h"
@@ -38,7 +38,7 @@
 #include "atlas_level1.h"
 #include "cblas.h"
 
-double cblas_dsdot(const int N, const float *X, const int incX, 
+double cblas_dsdot(const int N, const float *X, const int incX,
                    const float *Y, const int incY)
 {
    if (N > 0)
