@@ -1,3 +1,35 @@
+/*
+ *             Automatically Tuned Linear Algebra Software v3.3.3Dev
+ **************** THIS IS AN UNSUPPORTED DEVELOPER RELEASE *****************
+ *                   (C) Copyright 1999 Peter Soendergaard
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *   1. Redistributions of source code must retain the above copyright
+ *      notice, this list of conditions and the following disclaimer.
+ *   2. Redistributions in binary form must reproduce the above copyright
+ *      notice, this list of conditions, and the following disclaimer in the
+ *      documentation and/or other materials provided with the distribution.
+ *   3. The name of the University of Tennessee, the ATLAS group,
+ *      or the names of its contributers may not be used to endorse
+ *      or promote products derived from this software without specific
+ *      written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE UNIVERSITY OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ *
+ */
+
 #define SSE
 #include "SSE3Dnow.h"
 #include "atlas_misc.h"
@@ -7,7 +39,7 @@ void ATL_USERMM
 
 {
    /*--- program info ---*/
-   /*  $Revision: 1.7 $  */
+   /*  $Revision: 1.1.1.1 $  */
    /*  loadfirst = 'a'  */
    /*  nu = 1  */
    /*  k_loop = None  */
@@ -17,12 +49,12 @@ void ATL_USERMM
    /*  n_cleanup = {}  */
    /*  mu = 2  */
    /*  ku = 4  */
-   /*  rev = '$Revision: 1.7 $'  */
+   /*  rev = '$Revision: 1.1.1.1 $'  */
    /*  applyfilter = 0  */
    /*  align_jumps = 0  */
    /*  prec = 'single'  */
    /*  m_cleanup = {}  */
-   /*  used_outside_len = 60  */
+   /*  used_outside_len = 64  */
    /*  k_cleanup = {'mustfit': 56, 'method': 'acc1', 'compile': 1}  */
    /*  outputdir = 'Linux_PIII/'  */
    /*  arch = 'sse'  */
@@ -30,7 +62,7 @@ void ATL_USERMM
    /*  atlasname = 'Linux_PIII'  */
    /*  method = 'acc'  */
    /*  used_lastuse = 'b'  */
-   /*  outside_len = 60  */
+   /*  outside_len = 64  */
    /*  lastuse = 1  */
    /*  veclen = 4  */
    /*  sched = ['fuse', 'spread']  */
@@ -48,8 +80,8 @@ void ATL_USERMM
    float *pC0 = C;
    const float *stM = A + MB*KB;
    const float *stN = B + NB*KB;
-   const int incAm = 2*KB-KB+60;
-   const int incBm = -KB+60;
+   const int incAm = 2*KB-KB+64;
+   const int incBm = -KB+64;
    const int incCm = (2 SHIFT);
    const int incAn = -MB*KB;
    const int incBn = 1*KB;
@@ -163,11 +195,17 @@ void ATL_USERMM
          vec_add_rr(reg3,reg0);
          vec_mul_mr_a(pA0+52+KB,reg6);
          vec_add_rr(reg6,reg1);
-         vec_mov_mr_a(pB0+56,reg5);
-         vec_mov_mr_a(pA0+56,reg2);
+         vec_mov_mr_a(pB0+56,reg7);
+         vec_mov_mr_a(pA0+56,reg4);
+         vec_mul_rr(reg7,reg4);
+         vec_add_rr(reg4,reg0);
+         vec_mul_mr_a(pA0+56+KB,reg7);
+         vec_add_rr(reg7,reg1);
+         vec_mov_mr_a(pB0+60,reg5);
+         vec_mov_mr_a(pA0+60,reg2);
          vec_mul_rr(reg5,reg2);
          vec_add_rr(reg2,reg0);
-         vec_mul_mr_a(pA0+56+KB,reg5);
+         vec_mul_mr_a(pA0+60+KB,reg5);
          vec_add_rr(reg5,reg1);
          vec_sum(reg0);
          vec_sum(reg1);
